@@ -3,12 +3,11 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KDECORATION2_DECORATIONBUTTONGROUP_P_H
-#define KDECORATION2_DECORATIONBUTTONGROUP_P_H
+#pragma once
 #include "decorationbuttongroup.h"
 
+#include <QList>
 #include <QRectF>
-#include <QVector>
 
 //
 //  W A R N I N G
@@ -36,7 +35,7 @@ public:
 
     Decoration *decoration;
     QRectF geometry;
-    QVector<QPointer<DecorationButton>> buttons;
+    QList<DecorationButton *> buttons;
     qreal spacing;
 
 private:
@@ -44,5 +43,3 @@ private:
 };
 
 } // namespace
-
-#endif
